@@ -804,8 +804,7 @@ PHP_FUNCTION(grapheme_extract)
 		} else {
 			ZVAL_DEREF(next);
 			/* initialize next */
-			SEPARATE_ZVAL_NOREF(next);
-			zval_dtor(next);
+			zval_ptr_dtor(next);
             ZVAL_LONG(next, lstart);
 		}
 	}
