@@ -24,6 +24,6 @@
 
 int zend_accel_script_persistable(zend_persistent_script *script);
 uint32_t zend_accel_script_persist_calc(zend_persistent_script *script, char *key, unsigned int key_length, int for_shm);
-zend_persistent_script *zend_accel_script_persist(zend_persistent_script *script, char **key, unsigned int key_length);
+zend_persistent_script *zend_accel_script_persist(zend_persistent_script *script, char **key, unsigned int key_length, int for_shm);
 
 #endif /* ZEND_PERSIST_H */
